==> qtjambi-scxml-6.2.2-sources.jar: io/qt/scxml/QScxmlCppDataModel.java <==
package io.qt.scxml;


/**
 * <p>C++ data model for a Qt SCXML state machine</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html">QScxmlCppDataModel</a></p>
 */
public abstract class QScxmlCppDataModel extends io.qt.scxml.QScxmlDataModel
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlCppDataModel.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScxmlCppDataModel {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public boolean evaluateToBool(int id, boolean[] ok){
            return evaluateToBool_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native boolean evaluateToBool_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String evaluateToString(int id, boolean[] ok){
            return evaluateToString_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native java.lang.String evaluateToString_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.Object evaluateToVariant(int id, boolean[] ok){
            return evaluateToVariant_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native java.lang.Object evaluateToVariant_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
        
        @Override
        @io.qt.QtUninvokable
        public void evaluateToVoid(int id, boolean[] ok){
            evaluateToVoid_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native void evaluateToVoid_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlCppDataModel(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlCppDataModel() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html#QScxmlCppDataModel">QScxmlCppDataModel::QScxmlCppDataModel(QObject*)</a></p>
     */
    public QScxmlCppDataModel(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QScxmlCppDataModel instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html#inState">QScxmlCppDataModel::inState(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean inState(java.lang.String stateName){
        return inState_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), stateName);
    }
    
    @io.qt.QtUninvokable
    private native boolean inState_native_cref_QString_constfct(long __this__nativeId, java.lang.String stateName);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html#scxmlEvent">QScxmlCppDataModel::scxmlEvent()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.scxml.QScxmlEvent scxmlEvent(){
        return scxmlEvent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlEvent scxmlEvent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#setScxmlEvent">QScxmlDataModel::setScxmlEvent(QScxmlEvent)</a></p>
     */
    public final void setScxmlEvent(io.qt.scxml.QScxmlEvent scxmlEvent){
        setScxmlEvent_native_cref_QScxmlEvent(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(scxmlEvent));
    }
    
    private native void setScxmlEvent_native_cref_QScxmlEvent(long __this__nativeId, long scxmlEvent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#evaluateAssignment">QScxmlDataModel::evaluateAssignment(QScxmlExecutableContent::EvaluatorId,bool*)</a></p>
     */
    @io.qt.QtUninvokable
    public void evaluateAssignment(int id, boolean[] ok){
        evaluateAssignment_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
    }
    
    @io.qt.QtUninvokable
    private native void evaluateAssignment_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#evaluateForeach">QScxmlDataModel::evaluateForeach(QScxmlExecutableContent::EvaluatorId,bool*,QScxmlDataModel::ForeachLoopBody*)</a></p>
     */
    @io.qt.QtUninvokable
    public void evaluateForeach(int id, boolean[] ok, io.qt.scxml.QScxmlDataModel.ForeachLoopBody body){
        evaluateForeach_native_int_bool_ptr_QScxmlDataModel_ForeachLoopBody_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok, QtJambi_LibraryUtilities.internal.checkedNativeId(body));
    }
    
    @io.qt.QtUninvokable
    private native void evaluateForeach_native_int_bool_ptr_QScxmlDataModel_ForeachLoopBody_ptr(long __this__nativeId, int id, boolean[] ok, long body);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#evaluateInitialization">QScxmlDataModel::evaluateInitialization(QScxmlExecutableContent::EvaluatorId,bool*)</a></p>
     */
    @io.qt.QtUninvokable
    public void evaluateInitialization(int id, boolean[] ok){
        evaluateInitialization_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
    }
    
    @io.qt.QtUninvokable
    private native void evaluateInitialization_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#hasScxmlProperty">QScxmlDataModel::hasScxmlProperty(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean hasScxmlProperty(java.lang.String name){
        return hasScxmlProperty_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasScxmlProperty_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#scxmlProperty">QScxmlDataModel::scxmlProperty(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Object scxmlProperty(java.lang.String name){
        return scxmlProperty_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object scxmlProperty_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#setScxmlProperty">QScxmlDataModel::setScxmlProperty(QString,QVariant,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean setScxmlProperty(java.lang.String name, java.lang.Object value, java.lang.String context){
        return setScxmlProperty_native_cref_QString_cref_QVariant_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, value, context);
    }
    
    @io.qt.QtUninvokable
    private native boolean setScxmlProperty_native_cref_QString_cref_QVariant_cref_QString(long __this__nativeId, java.lang.String name, java.lang.Object value, java.lang.String context);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#setup">QScxmlDataModel::setup(QVariantMap)</a></p>
     */
    public boolean setup(java.util.Map<java.lang.String, java.lang.Object> initialDataValues){
        return setup_native_cref_QMap(QtJambi_LibraryUtilities.internal.nativeId(this), initialDataValues);
    }
    
    private native boolean setup_native_cref_QMap(long __this__nativeId, java.util.Map<java.lang.String, java.lang.Object> initialDataValues);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlCppDataModel(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScxmlCppDataModel(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScxmlCppDataModel instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-scxml-6.3.4-sources.jar: io/qt/scxml/QScxmlCppDataModel.java <==
package io.qt.scxml;


/**
 * <p>C++ data model for a Qt SCXML state machine</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html">QScxmlCppDataModel</a></p>
 */
public abstract class QScxmlCppDataModel extends io.qt.scxml.QScxmlDataModel
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlCppDataModel.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QScxmlCppDataModel {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public boolean evaluateToBool(int id, boolean[] ok){
            return evaluateToBool_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native boolean evaluateToBool_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String evaluateToString(int id, boolean[] ok){
            return evaluateToString_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native java.lang.String evaluateToString_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.Object evaluateToVariant(int id, boolean[] ok){
            return evaluateToVariant_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native java.lang.Object evaluateToVariant_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
        
        @Override
        @io.qt.QtUninvokable
        public void evaluateToVoid(int id, boolean[] ok){
            evaluateToVoid_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
        }
        @io.qt.QtUninvokable
        private native void evaluateToVoid_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlCppDataModel(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlCppDataModel() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html#QScxmlCppDataModel">QScxmlCppDataModel::QScxmlCppDataModel(QObject*)</a></p>
     */
    public QScxmlCppDataModel(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QScxmlCppDataModel instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html#inState">QScxmlCppDataModel::inState(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean inState(java.lang.String stateName){
        return inState_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), stateName);
    }
    
    @io.qt.QtUninvokable
    private native boolean inState_native_cref_QString_constfct(long __this__nativeId, java.lang.String stateName);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlcppdatamodel.html#scxmlEvent">QScxmlCppDataModel::scxmlEvent()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.scxml.QScxmlEvent scxmlEvent(){
        return scxmlEvent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.scxml.QScxmlEvent scxmlEvent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#setScxmlEvent">QScxmlDataModel::setScxmlEvent(QScxmlEvent)</a></p>
     */
    public final void setScxmlEvent(io.qt.scxml.QScxmlEvent scxmlEvent){
        setScxmlEvent_native_cref_QScxmlEvent(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(scxmlEvent));
    }
    
    private native void setScxmlEvent_native_cref_QScxmlEvent(long __this__nativeId, long scxmlEvent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#evaluateAssignment">QScxmlDataModel::evaluateAssignment(QScxmlExecutableContent::EvaluatorId,bool*)</a></p>
     */
    @io.qt.QtUninvokable
    public void evaluateAssignment(int id, boolean[] ok){
        evaluateAssignment_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
    }
    
    @io.qt.QtUninvokable
    private native void evaluateAssignment_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#evaluateForeach">QScxmlDataModel::evaluateForeach(QScxmlExecutableContent::EvaluatorId,bool*,QScxmlDataModel::ForeachLoopBody*)</a></p>
     */
    @io.qt.QtUninvokable
    public void evaluateForeach(int id, boolean[] ok, io.qt.scxml.QScxmlDataModel.ForeachLoopBody body){
        evaluateForeach_native_int_bool_ptr_QScxmlDataModel_ForeachLoopBody_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok, QtJambi_LibraryUtilities.internal.checkedNativeId(body));
    }
    
    @io.qt.QtUninvokable
    private native void evaluateForeach_native_int_bool_ptr_QScxmlDataModel_ForeachLoopBody_ptr(long __this__nativeId, int id, boolean[] ok, long body);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#evaluateInitialization">QScxmlDataModel::evaluateInitialization(QScxmlExecutableContent::EvaluatorId,bool*)</a></p>
     */
    @io.qt.QtUninvokable
    public void evaluateInitialization(int id, boolean[] ok){
        evaluateInitialization_native_int_bool_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), id, ok);
    }
    
    @io.qt.QtUninvokable
    private native void evaluateInitialization_native_int_bool_ptr(long __this__nativeId, int id, boolean[] ok);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#hasScxmlProperty">QScxmlDataModel::hasScxmlProperty(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean hasScxmlProperty(java.lang.String name){
        return hasScxmlProperty_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasScxmlProperty_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#scxmlProperty">QScxmlDataModel::scxmlProperty(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Object scxmlProperty(java.lang.String name){
        return scxmlProperty_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object scxmlProperty_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#setScxmlProperty">QScxmlDataModel::setScxmlProperty(QString,QVariant,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean setScxmlProperty(java.lang.String name, java.lang.Object value, java.lang.String context){
        return setScxmlProperty_native_cref_QString_cref_QVariant_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, value, context);
    }
    
    @io.qt.QtUninvokable
    private native boolean setScxmlProperty_native_cref_QString_cref_QVariant_cref_QString(long __this__nativeId, java.lang.String name, java.lang.Object value, java.lang.String context);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmldatamodel.html#setup">QScxmlDataModel::setup(QVariantMap)</a></p>
     */
    public boolean setup(java.util.Map<java.lang.String, ? extends java.lang.Object> initialDataValues){
        return setup_native_cref_QMap(QtJambi_LibraryUtilities.internal.nativeId(this), initialDataValues);
    }
    
    private native boolean setup_native_cref_QMap(long __this__nativeId, java.util.Map<java.lang.String, ? extends java.lang.Object> initialDataValues);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlCppDataModel(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QScxmlCppDataModel(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QScxmlCppDataModel instance, QDeclarativeConstructor constructor);
    
}
